Lua_BiWuPanel = class("Lua_BiWuPanel", Lua_DisplayObject);
function Lua_BiWuPanel:ctor(p)
    self:superCall("ctor", p, "BiWuPanel_skin");
end

function Lua_BiWuPanel:buildShowItem()
    self:superCall("buildShowItem");

    self.biwu_draglist = Lua_DragList.new(self.content, 2, Vector4(284, -172, 1095, 504));
    self.biwu_draglist:setLocation(-349, 192, 0);
    self.biwu_draglist:setListCell(Lua_BiWuItem, 510, 275, 4);
    self.biwu_draglist.canDrag = false;
    self.biwu_draglist:setSubPos(17, 3);

    self.isCombine = 0;
    self.combineBox.seleted = false;
    self.redDot:setEnable(false);
    self:addListener();

    Lua_ProxyManager.getProxy("Lua_GamePlayProxy"):sArenaPanelInfo();
end

function Lua_BiWuPanel:addListener()
    self.shopIcon:addClickFuntion(self, self.onShopClick);
    self.jiangliIcon:addClickFuntion(self, self.onJiangLiClick);
    self.jiluIcon:addClickFuntion(self, self.onJiLuClick);
    self.plusBg:addClickFuntion(self, self.onPlusClick);
    self.exchangeBtn:addClickFuntion(self, self.onExchangeClick);
    self.combineBox:addBoxChange(self, self.onCombineBoxChange);

    self:addLuaEvent("rArenaPanelInfo", self, self.onArenaPanelInfo);
    self:addLuaEvent("rGetArenaRankRewards", self, self.onGetRankRewards);
    self:addLuaEvent("BuyTimesInfoUpdate", self, self.onBuyChallengeTimes);
    self:addLuaEvent("BI_WU_CHALLENGE", self, self.onChallenge);   
end

-- 刷新挑战列表
function Lua_BiWuPanel:updateChallengeList()
    local list = DataCenter.gamePlayData.challengeList;
    if list ~= nil then
        local arr = Array();
        for i = 1, 4 do
            arr:add(list[i]);
        end
        self.biwu_draglist:setLuaArrayData(arr, false);

        local ownInfo = list[5];
        if ownInfo ~= nil then
            self.rankLbl.text = LanUtil.formateStr(LanUtil.getValue(120903), tostring(ownInfo.rank));
            self.forceLbl.text = LanUtil.formateStr(LanUtil.getValue(120904), tostring(ownInfo.force));
        end
    end
end

-- 更新剩余次数
function Lua_BiWuPanel:updateTimes()
    local times = DataCenter.gamePlayData.curChallengeTimes;
    if times == nil or times < 0 then
        times = 0;
    end

    local str = "";
    if times > 0 then
        str = "["..Lua_ColorDefine.GREEN_STR.."]"..tostring(times).."[-]";
    else
        str = "["..Lua_ColorDefine.RED_STR.."]"..tostring(times).."[-]";
    end
    self.timesLbl.text = LanUtil.formateStr(LanUtil.getValue(120905), str);
end

-- 更新排行奖励按钮特效
function Lua_BiWuPanel:updateRankRewardEff()
    if DataCenter.gamePlayData.rankRewardState == 0 then
        self.redDot:setEnable(true);
    else
        self.redDot:setEnable(false);
    end
end

function Lua_BiWuPanel:onArenaPanelInfo()
    self:updateRankRewardEff();
    self:updateChallengeList();
    self:updateTimes();
    self:updateRefreshChallengeBtn();  -- 刷新【换一下】按钮
end

function Lua_BiWuPanel:onGetRankRewards()
    OperateAlert.show(LanUtil.getValue(120908));
    self:updateRankRewardEff();
end

function Lua_BiWuPanel:onBuyChallengeTimes()
    self:updateTimes();
end

function Lua_BiWuPanel:onShopClick(args)
    Lua_WindowUtil.openWin("Lua_ShopWindow", WinParam.ACTION_OPEN, 6);
end

function Lua_BiWuPanel:onJiangLiClick(args)
    if DataCenter.gamePlayData.rankRewardState == 0 then
        Lua_ProxyManager.getProxy("Lua_GamePlayProxy"):sGetRankRewards();
    else
        Lua_WindowUtil.openWin("Lua_BiWuRankRewardsWindow");
    end
end

function Lua_BiWuPanel:onJiLuClick(args)
    Lua_ProxyManager.getProxy("Lua_GamePlayProxy"):sArenaRecordsInfo();
    Lua_WindowUtil.openWin("Lua_BiwuRecordsWindow");
end

function Lua_BiWuPanel:onPlusClick(args)
    local info = {};
    info.owner = self;
    info.configSign = "area";
    info.residueTimes = DataCenter.gamePlayData.curCanBuyTimes;
    -- info.eachCost = getConfig({"arena_plus_info", "buy_cost_money", "value"});
    info.costList = DataCenter.gamePlayData:getBiWuByTimesCost();
    info.costType = Lua_MoneyData.GOLD;
    info.callback = self.onBuyTimes;
    Lua_WindowUtil.openWin("Lua_BuyTimesWindow", WinParam.ACTION_OPEN, info);
end

function Lua_BiWuPanel:onBuyTimes(val)
    Lua_ProxyManager.getProxy("Lua_GamePlayProxy"):sBuyChallengeTimes(tonumber(val));
end

function Lua_BiWuPanel:onExchangeClick(args)
    if DataCenter.gamePlayData.oldClickChangeListTime > 0 then
        OperateAlert.show(LanUtil.getValue(120911));
        return;
    end

    Lua_ProxyManager.getProxy("Lua_GamePlayProxy"):sChangeChallengeList();
end

function Lua_BiWuPanel:updateRefreshChallengeBtn()
    local str = "";
    if DataCenter.gamePlayData.oldClickChangeListTime <= 0 then -- CD过了
        if self.hasRefreshTimer ~= nil and self.hasRefreshTimer == true then
            Lua_CommonUtil.removeTimer(self, self.updateRefreshChallengeListTime);
            self.hasRefreshTimer = false;
        end
        str = "";
        self.exchangeLbl.text = LanUtil.formateStr(LanUtil.getValue(120912), str);
        self.exchangeBtn:setGray(false);
    else
        if self.hasRefreshTimer == nil or self.hasRefreshTimer == false then
            Lua_CommonUtil.addTimer("updateRefreshChallengeListTime", 1, self, self.updateRefreshChallengeListTime, nil, -1);
            self.hasRefreshTimer = true;
        end
        str = LanUtil.StringProfile(tostring(DataCenter.gamePlayData.oldClickChangeListTime), LanUtil.getValue(26));
        self.exchangeLbl.text = str;
        self.exchangeBtn:setGray(true);
    end
    -- self.exchangeLbl.text = LanUtil.formateStr(LanUtil.getValue(120912), str);
end

function Lua_BiWuPanel:updateRefreshChallengeListTime()
    DataCenter.gamePlayData.oldClickChangeListTime = DataCenter.gamePlayData.oldClickChangeListTime - 1;
    if DataCenter.gamePlayData.oldClickChangeListTime <= 0 then -- CD过了
        if self.hasRefreshTimer ~= nil and self.hasRefreshTimer == true then
            Lua_CommonUtil.removeTimer(self, self.updateRefreshChallengeListTime);
            self.hasRefreshTimer = false;
        end
        str = "";
        self.exchangeLbl.text = LanUtil.formateStr(LanUtil.getValue(120912), str); 
        self.exchangeBtn:setGray(false);
    else
        str = LanUtil.StringProfile(tostring(DataCenter.gamePlayData.oldClickChangeListTime), LanUtil.getValue(26));
        self.exchangeLbl.text = str;
        self.exchangeBtn:setGray(true);
    end
    -- self.exchangeLbl.text = LanUtil.formateStr(LanUtil.getValue(120912), str); 
end

function Lua_BiWuPanel:onCombineBoxChange(val)
    local lv = getConfig({"arena_plus_info", "combine_level", "value"});
    if lv > DataCenter.roleData.level then
        OperateAlert.show(LanUtil.formateStr(LanUtil.getValue(120960), lv));
        val = false;
    end

    if val == true then
        self.isCombine = 1;
        self.combineBox.seleted = true;
    else
        self.isCombine = 0;
        self.combineBox.seleted = false;
    end
end
function Lua_BiWuPanel:onChallenge(data)
    self.data = data
    if self.data ~= nil then
        Lua_ProxyManager.getProxy("Lua_GamePlayProxy"):sArenaChallenge(self.data.id, self.data.rank, self.isCombine);
        Lua_WindowUtil.openWin("Lua_GamePlayWindow", WinParam.ACTION_CLOSE, nil);
    end
end
function Lua_BiWuPanel:dispose()
    if self.biwu_draglist ~= nil then
        self.biwu_draglist:dispose();
        self.biwu_draglist = nil;
    end

    if self.hasRefreshTimer ~= nil and self.hasRefreshTimer == true then
        Lua_CommonUtil.removeTimer(self, self.updateRefreshChallengeListTime);
        self.hasRefreshTimer = false;
    end

    self:superCall("dispose");
end









Lua_BiWuItem = class("Lua_BiWuItem", Lua_ListCell);
function Lua_BiWuItem:ctor(p)
    self:superCall("ctor", p, "BiWuItem_skin");
end

function Lua_BiWuItem:buildShowItem()
    self:superCall("buildShowItem");
    self.fightNum = Lua_NumberImage.new(self.content);
    --self.fightNum.prefix = "f_";
    self.fightNum.num = 123456;
    self.fightNum.numWidth = 13;
    self.fightNum:setDepth(4);
    self.fightNum:setLocation(0, 158, 0);

    self.rankNum = Lua_NumberImage.new(self.content);
    self.rankNum.prefix = "ui_daily_font_";
    self.rankNum.num = 123456;
    self.rankNum.numWidth = 12;
    self.rankNum:setDepth(4);
    self.rankNum:setLocation(-3, -138, 0);

    self.challengeBtn:addClickFuntion(self, self.onChallengeBtnClick);
end

function Lua_BiWuItem:onChallengeBtnClick(go)
    -- 挑战次数不足
    if DataCenter.gamePlayData.curChallengeTimes <= 0 then
        OperateAlert.show(LanUtil.getValue(120907));
        -- local info = {};
        -- info.owner = self;
        -- info.configSign = "area";
        -- info.residueTimes = DataCenter.gamePlayData.curCanBuyTimes;
        -- info.eachCost = getConfig({"arena_plus_info", "buy_cost_money", "value"});
        -- info.costType = Lua_MoneyData.GOLD;
        -- info.callback = self.onBuyTimes;
        -- Lua_WindowUtil.openWin("Lua_BuyTimesWindow", WinParam.ACTION_OPEN, info);
        local info = {};
        info.owner = self;
        info.configSign = "area";
        info.residueTimes = DataCenter.gamePlayData.curCanBuyTimes;
        info.costList = DataCenter.gamePlayData:getBiWuByTimesCost();
        info.costType = Lua_MoneyData.GOLD;
        info.callback = self.onBuyTimes;
        Lua_WindowUtil.openWin("Lua_BuyTimesWindow", WinParam.ACTION_OPEN, info);
        return;
    end

    if self.data ~= nil then
        Lua_MsgUtil.callFunc("BI_WU_CHALLENGE", self.data);       
    end
end

function Lua_BiWuItem:onBuyTimes(val)
    Lua_ProxyManager.getProxy("Lua_GamePlayProxy"):sBuyChallengeTimes(tonumber(val));
end

function Lua_BiWuItem:setData(data)
    self.data = data;
    if self.data ~= nil then
        self.fightNum.num = self.data.force;
        -- 自己
        if tonumber(DataCenter.roleData.roleId) == tonumber(self.data.id) then
            self.nameLbl.text = "["..Lua_ColorDefine.GREEN_STR.."]"..self.data.name.."[-]";
            self.challengeBtn:setEnable(false);
        else
            self.nameLbl.text = self.data.name;
            self.challengeBtn:setEnable(true);
        end
        -- self.rankLbl.text = LanUtil.formateStr(LanUtil.getValue(120906), tostring(self.data.rank));
        -- self.rankLbl:setLocation(-(self.rankLbl.width / 2) - 4, -138);
        self.rankNum.num = self.data.rank;
    else
        self.nameLbl.text = "";
        -- self.rankLbl.text = "";
        self.rankNum.num = 0;
        self.fightNum.num = 0;
    end

    self:updateRoleModel();
end

function Lua_BiWuItem:updateRoleModel()
    if self.data ~= nil then
        if self.playerModel == nil then
            self.playerModel = ModelPlayer();
        end

        -- 角色
        local modelData = UsData();
        modelData.roleId = self.data.id; -- 
        modelData.nickname = self.data.name; -- 
        modelData.gender = self.data.sex; -- 性别
        modelData.weapon_id = self.data.shape_info.weapon; -- 武器
        modelData.clothes_id = self.data.shape_info.clothes; -- 衣服
        modelData.fashion_weapon_id = self.data.shape_info.fashion_weapon_id; -- 
        modelData.fashion_clothes_id = self.data.shape_info.fashion_clothes_id; -- 
        modelData.fashionHeadId = self.data.shape_info.fashion_headdress_id; -- 
        modelData.lvl = self.data.level; -- 等级
        modelData.career = self.data.career; -- 职业
        modelData.wingId = self.data.shape_info.wing; -- 仙羽等级
        modelData.profession = self.data.profession; -- 当前转职次数
        modelData.showShadow = false;
        modelData.canBeClick = false;
        modelData.isShowName = false;
        modelData.IsUI = true;
        modelData.hp = 1;
        modelData.kind = 1;

        self.playerModel:init(self.content, Vector3(-8, -108, -13), Vector3(0, 90, 0), modelData, nil, 125);
        self.playerModel:SetRenderQueue(self.nameLbl, -1, 2);
        self.playerModel:setGray(false);
        self.playerModel:setActive(true);
    else
        if self.playerModel ~= nil then
            self.playerModel:setActive(false);
        end
    end
end

function Lua_BiWuItem:onPlayerSoundClick(go)

end

function Lua_BiWuItem:dispose()
    if self.playerModel ~= nil then
        self.playerModel:dispose();
    end
    self:superCall("dispose");
end