Lua_CopyTeamWindow = class("Lua_CopyTeamWindow", Lua_Window);
function Lua_CopyTeamWindow:ctor()
	self:superCall("ctor");
end

function Lua_CopyTeamWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.addSp:setEnable(false);

	self.rewardItem = Lua_RewardItem.new(self.content);
	self.rewardItem:setDepth(5);
	self.rewardItem:setClickWin(true);
	self.rewardItem:setLocation(-521.5, -266, 0);

	self.oneBtn:addClickFuntion(self, self.onOneEnterClick);
	self.subBtn:addClickFuntion(self, self.onEnterClick);
	self.saoBtn:addClickFuntion(self, self.onSaoClick);

	self:addLuaEvent("COPY_DATA_UPDATE", self, self.onCopyDataUpdate);
end

function Lua_CopyTeamWindow:onCopyDataUpdate()
	local copyVo = self.data; -- Lua_CopyVo
	self.titleName.text = copyVo.name;
	self.copyList = Array();

	local config;
	local degree_amount = copyVo.degree_amount;
	local targetIndex = 1;
	for i = 1, degree_amount do
		config = getConfig({ copyVo.another_config, 2000000 + 1000 * copyVo.script_type + i });
		config.index = i;
		config.dif = i;
		config.script_type = copyVo.script_type;
		if i ~= 1 then
			config.starOk = config.open_star <= copyVo:getDegressStar(i - 2);
		else
			config.starOk = true;
		end

		if copyVo.id == Lua_CopyData.XIELING_COPY then
			if copyVo:getCopyMinLv(i) <= DataCenter.roleData.level then
				targetIndex = i;
			end
		else
			if copyVo:getCopyMinLv(i) <= DataCenter.roleData.level and config.starOk then
				if config.dif == 1 or copyVo:isDegressPass(config.dif - 1) == true then
					targetIndex = i;
				end
			end
		end
		self.copyList:add(config);
	end

	if self.curData == nil then
		self:onDragListSelected(self.copyList[targetIndex]);
		self.dragList:moveToIndex(targetIndex, true);
	else
		self:onDragListSelected(self.curData);
	end

	if copyVo.leftTimes == nil or copyVo.leftTimes <= 0 then
		self.timeTxt.text = LanUtil.formateStr(LanUtil.getValue(121109), "0");
	else
		self.timeTxt.text = LanUtil.formateStr(LanUtil.getValue(121109), tostring(copyVo.leftTimes));
	end
end

function Lua_CopyTeamWindow:onOneEnterClick(go)
	if self:checkEnter() == false then
		return;
	end

	if self.curData.open_level > DataCenter.roleData.level then
		OperateAlert.show(LanUtil.getValue(121115));
		return;
	end
	Lua_CopyUtil.enterCopy(self.data.id, self.curData.dif);
end

function Lua_CopyTeamWindow:checkEnter()
	local copyVo = self.data;
	if copyVo.config.cost ~= nil and (copyVo.leftTimes == nil or copyVo.leftTimes <= 0) then
		local maxVipLv = getConfig({"vip_const", "max_vip_lv", "value"});
		local t = copyVo.leftBuyTimes;
		if DataCenter.roleData.vipType == maxVipLv and (t == nil or t == 0) then
			return true;
		end
		OperateAlert.show(LanUtil.getValue(121158));
		self:onAddClick();
		return false;
	end
	return true;
end

function Lua_CopyTeamWindow:onAddClick(go)
	local copyVo = self.data;
	local t = copyVo.leftBuyTimes == nil and 0 or copyVo.leftBuyTimes;
	Lua_WindowUtil.openWin("Lua_BuyTimesWindow", WinParam.ACTION_OPEN, {owner = self,
		configSign = "money_copy_buy_times", residueTimes = t, costList = copyVo:getBuyTimeCostList(),
		costType = copyVo:getBuyTimeCostType(), callback = self.onBuyTimes, useGold = 1});
end

function Lua_CopyTeamWindow:onEnterClick(go)
	if self.curData.open_level > DataCenter.roleData.level then
		OperateAlert.show(LanUtil.getValue(121115));
		return;
	end

	local td = DataCenter.teamData;
	if td.hasTeam == false then
		Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {des = LanUtil.getValue(122242), owner = self, type = 1, subFun = self.onCreateTeam});
	else
		if td.amILeader == true then
			if td.teamerArr:getSize() == 1 then
				Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {des = LanUtil.getValue(122243), owner = self, type = 1, subFun = self.onOnlyOneEnter});
			else
				td:enterCopy(self.data.id, self.curData.dif);
			end
		else
			OperateAlert.show(LanUtil.getValue(122241));
		end
	end
end

function Lua_CopyTeamWindow:onCreateTeam(o)
	local td = DataCenter.teamData;
	td:setTeamTargetByCopy(self.data.id, self.curData.dif, true);

	local cmd = ProtoPublic_pb.Proto10100302();
	cmd.team_type = 3;
	cmd.level_low = td.minLv;
	cmd.lelev_upper = td.maxLv;
	cmd.script_type = self.data.id;
	cmd.script_degree = self.curData.dif;
	sendMsg(10100302, cmd);
end

function Lua_CopyTeamWindow:onOnlyOneEnter(o)
	if self:checkEnter() == false then
		return;
	end
	local td = DataCenter.teamData;
	td:enterCopy(self.data.id, self.curData.dif);
end

function Lua_CopyTeamWindow:onSaoClick(go)
	if self.curData.open_level > DataCenter.roleData.level then
		OperateAlert.show(LanUtil.getValue(121115));
		return;
	end

	local td = DataCenter.teamData;
	if td.hasTeam == true and td.amILeader == false then
		OperateAlert.show(LanUtil.getValue(122248));
		return;
	end
	Lua_WindowUtil.openWin("Lua_TeamWindow", nil, { act = 1, script_type = self.data.id, script_degree = self.curData.dif });
end

function Lua_CopyTeamWindow:dispose()
	if self.rewardItem ~= nil then
		self.rewardItem:dispose();
		self.rewardItem = nil;
	end

	self:superCall("dispose");
end