Lua_CopyZodiacWindow = class("Lua_CopyZodiacWindow", Lua_Window);
function Lua_CopyZodiacWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_CopyZodiacWindow";
	self.skinName = "CopyZodiacWindow_skin";
end

function Lua_CopyZodiacWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.btnList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 306, 440));
	self.btnList:setListCell(Lua_CopyZodiacBtnItem, 109, 306, 1);
	self.btnList:setLocation(-400, 16, 0);

	self.rewardList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 270, 180));
	self.rewardList:setListCell(Lua_CopyZodiacReward, 90, 90, 3);
	self.rewardList:setLocation(405, -63, 0);
	self.rewardList.canDrag = false;

	self.rewardDes.text = LanUtil.getValue(143604);
	self.rewardDes.clickScale = false;
	self.rewardDes:addClickFuntion(self, self.onRewardDesClick);
	self.helpSp:addClickFuntion(self, self.onHelpBtnClick);
	self.addBtn:addClickFuntion(self, self.onAddBtnClick);
	self.upBtn:addClickFuntion(self, self.onUpBtnClick);
	self.enterBtn:addClickFuntion(self, self.onEnterClick);
	self.saoBtn:addClickFuntion(self, self.onSaoDangClick);
	self.zodiacBtn:addClickFuntion(self, self.onZodiacBtnClick);

	self:addLuaEvent("COPY_DATA_UPDATE", self, self.onCopyDataUpdate);
	self:addLuaEvent("CopyZodiacBtnSelected", self, self.onBtnSelected);
	Lua_CopyUtil.sendGetCopyInfoMsg(Lua_CopyData.ZODIAC_COPY);
end

function Lua_CopyZodiacWindow:dispose()
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.zodiacModel ~= nil then
		self.zodiacModel:dispose();
		self.zodiacModel = nil;
	end

	self:superCall("dispose");
end

function Lua_CopyZodiacWindow:showWin(param)
	local index_id;
	if type(param) == "table" then
		index_id = param.id;
	elseif type(param) == "number" then
		index_id = param;
	end

	-- 双倍副本活动开启后 显示UI
	local isOpenDouble = DataCenter.OpenDressCarnivalData:isOpenCopyDouble(tonumber(index_id))
	if DataCenter.OpenDressCarnivalData:isOpenCopyDoubleExp(tonumber(index_id)) == true or isOpenDouble then
		self.doubleExpObj:SetActive(true);
	else
		self.doubleExpObj:SetActive(false);
	end
end

function Lua_CopyZodiacWindow:onCopyDataUpdate()
	self.copyVo = DataCenter.copyData:getCopyById(Lua_CopyData.ZODIAC_COPY);

	self.btnList:setLuaArrayData(self.copyVo.zodiacInfoArr, false);
	local arr = self.btnList.showList;
	local len = arr:getSize();
	if len > 0 then
		local selectId = self.selectZodiacId;
		if selectId == nil then
			self.btnList:setSelected(1);
		else
			for i = 1, len do
				if arr[i].id == selectId then
					self.btnList:setSelected(i);
				end
			end
		end
	end
end

function Lua_CopyZodiacWindow:onBtnSelected(data)
	self.data = data;

	self.selectZodiacId = self.data.id;
	self.name.text = self.data.name;
	self.des.text = self.data.zodiac_desc;
	if self.data.isMaxDegree then
		self.nextJie.text = LanUtil.getValue(143610);
		self.needPower.text = LanUtil.formateStr(LanUtil.getValue(143603), self.data.powerName, tostring(self.data.zodiacPower));
		self.currentPower.text = "";
	else
		self.nextJie.text = LanUtil.formateStr(LanUtil.getValue(143601), tostring(self.data.rank + 1));
		self.needPower.text = LanUtil.formateStr(LanUtil.getValue(143602), self.data.powerName, tostring(self.data.upgrade[2]));
		self.currentPower.text = LanUtil.formateStr(LanUtil.getValue(143603), self.data.powerName, tostring(self.data.zodiacPower));
	end

	if self.data.isShowUpgradeRedDot then
		self.upBtn:setEnable(true);
		self.upRedDot:setEnable(true);
	else
		self.upBtn:setEnable(false);
		self.upRedDot:setEnable(false);
	end
	if DataCenter.roleData.level >= self.data.clean_level then
		self.saoBtn:setEnable(true);
	else
		self.saoBtn:setEnable(false);
	end
	if self.data.isOpen == 0 then
		self.enterBtn:setBtnEnable(false);
		self.saoBtn:setBtnEnable(false);
	else
		self.enterBtn:setBtnEnable(true);
		self.saoBtn:setBtnEnable(true);
	end
	self.rewardList:setLuaArrayData(self.data.rewardArr);
	self.leftTimes.text = LanUtil.formateStr(LanUtil.getValue(143605), tostring(self.copyVo.leftTimes), tostring(self.copyVo.sum_times));

	self:updateShowModel();
end

function Lua_CopyZodiacWindow:updateShowModel()
	if self.modelId == self.data.model_id then
		return;
	end
	self.modelId = self.data.model_id;

	if self.zodiacModel ~= nil then
		self.zodiacModel:dispose();
		self.zodiacModel = nil;
	end

	self.zodiacModel = UIModelTexture();
	self.zodiacModel:init(self.content, Vector2(0, 0), Vector2(1175, 680), 2, Vector3(0, 180, 0), Vector2(20, -250), 160);
	self.zodiacModel:setCamPos(10000, 0, 0);
	self.zodiacModel:setUrl("/model/"..self.data.model_id, self.data.model_id);
	self.zodiacModel:setRotEnable(true, 0, 0, 482, 484, 2);
	if self.data.isOpen == 0 then
		self.zodiacModel.uiEffect:setGray(true);
	else
		self.zodiacModel.uiEffect:setGray(false);
	end
end

function Lua_CopyZodiacWindow:onRewardDesClick(go)
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_CopyZodiacRewardWindow", WinParam.ACTION_OPEN, self.data);
end

function Lua_CopyZodiacWindow:onHelpBtnClick(go)
	Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_OPEN, LanUtil.getValue(143607));
end

function Lua_CopyZodiacWindow:onAddBtnClick(go)
	Lua_WindowUtil.openWin("Lua_BuyTimesWindow", WinParam.ACTION_OPEN, {owner = self, configSign = self.copyVo.vip_index, residueTimes = self.copyVo.leftBuyTimes,
	costList = self.copyVo:getBuyTimeCostList(), costType = self.copyVo:getBuyTimeCostType(), callback = self.onBuyTimes, useGold = 1});
end

function Lua_CopyZodiacWindow:onBuyTimes(val)
	Lua_CopyUtil.buyCopyTime(self.copyVo.id, val);
end

function Lua_CopyZodiacWindow:onUpBtnClick(go)
	if self.data == nil then
		return;
	end
	Lua_CopyUtil.bossUpgrade(self.data.degree);
end

function Lua_CopyZodiacWindow:onEnterClick(go)
	if self.data == nil then
		return;
	end

	if self:checkEnter() == false then
		return;
	end
	Lua_CopyUtil.enterCopy(self.copyVo.id, self.data.degree);
end

function Lua_CopyZodiacWindow:onSaoDangClick(go)
	if self.data == nil then
		return;
	end

	if self:checkEnter() == false then
		return;
	end

	local costVo = self.data.cleanCostVo;
	if costVo.haveNum >= costVo.count then
		self:onItemDirectOk();
	else
		local needGold = (costVo.count - costVo.haveNum) * Lua_CommonUtil.getCommonConfig("script_clean_gold", 1);
		local str = LanUtil.formateStr(LanUtil.getValue(121194), self.data.name, tostring(costVo.count),
			costVo.colorName, tostring(needGold), costVo.colorName);
		Lua_WindowUtil.openWin("Lua_ItemDirectBuyWindow", nil, { owner = self, callBack = self.onItemDirectOk,
		itemId = costVo.id, needNum = costVo.count, info = str });
	end
end

function Lua_CopyZodiacWindow:onItemDirectOk()
	Lua_CopyUtil.saoDangCopy(self.copyVo.id, self.data.degree);
end

function Lua_CopyZodiacWindow:checkEnter()
	if self.copyVo.leftTimes == nil or self.copyVo.leftTimes <= 0 then
		local maxVipLv = getConfig({"vip_const", "max_vip_lv", "value"});
		local t = self.copyVo.leftBuyTimes;
		if DataCenter.roleData.vipType == maxVipLv and (t == nil or t == 0) then
			return true;
		end
		OperateAlert.show(LanUtil.getValue(121158));
		self:onAddBtnClick();
		return false;
	end
	return true;
end

function Lua_CopyZodiacWindow:onZodiacBtnClick(go)
	Lua_WindowUtil.openWin("Lua_CopyZodiacWindow", WinParam.ACTION_CLOSE);
	Lua_WindowUtil.openWin("Lua_CopyWindow", WinParam.ACTION_CLOSE);
	Lua_WindowUtil.openWin("Lua_ZodiacWindow", WinParam.ACTION_OPEN, 1);
end





--------------------------------------------------





Lua_CopyZodiacBtnItem = class("Lua_CopyZodiacBtnItem", Lua_ListCell);
function Lua_CopyZodiacBtnItem:ctor(p)
	self:superCall("ctor", p, "CopyZodiacBtnItem_skin");
end

function Lua_CopyZodiacBtnItem:buildShowItem()
	self:superCall("buildShowItem");

	self.serverTime = tonumber(tostring(GlobalVar.cur_tick));
end

function Lua_CopyZodiacBtnItem:setData(data)
	self.data = data.vo;

	self.nameLab.text = self.data.name;
	self.headImg:setAltas(self.data.atlasName, self.data.iconName);
	if self.data.isOpen == 0 then
		self.leftTimeLab.text = self.data.openDes;
		Lua_CommonUtil.removeTimer(self, self.onLeftTimer);
	else
		self.endTime = self:getEndTime();
		self:updateLeftTime();
	end

	self.btnBg:setGray(self.data.isOpen == 0);
	self.nameBg:setGray(self.data.isOpen == 0);
	self.headImg:setGray(self.data.isOpen == 0);
	self.redDot:setEnable(self.data.isShowUpgradeRedDot);
end

function Lua_CopyZodiacBtnItem:onSelectionChange(val)
	self:superCall("onSelectionChange");

	if val then
		Lua_MsgUtil.callFunc("CopyZodiacBtnSelected", self.data);
	end
	self.selectIcon:setEnable(val);
end

function Lua_CopyZodiacBtnItem:updateLeftTime()
	self.left_time = self.endTime - DataCenter.roleData.serverTime;
	if self.left_time > 0 then
		self.leftTimeLab.text = LanUtil.formateStr(LanUtil.getValue(143600), TimeTransform.getInstance():transSeconds6(self.left_time, true, true));
		Lua_CommonUtil.addTimer("CopyZodiac_LeftTime", 1, self, self.onLeftTimer, nil, -1);
	else
		self.leftTimeLab.text = self.data.openDes;
		Lua_CommonUtil.removeTimer(self, self.onLeftTimer);
	end
end

function Lua_CopyZodiacBtnItem:onLeftTimer()
	self.left_time = self.endTime - DataCenter.roleData.serverTime;
	if self.left_time > 0 then
		self.leftTimeLab.text = LanUtil.formateStr(LanUtil.getValue(143600), TimeTransform.getInstance():transSeconds6(self.left_time, true, true));
	else
		self.leftTimeLab.text = self.data.openDes;
		Lua_CommonUtil.removeTimer(self, self.onLeftTimer);
		Lua_CopyUtil.sendGetCopyInfoMsg(Lua_CopyData.ZODIAC_COPY); -- 0点情况刷新数据
	end
end

function Lua_CopyZodiacBtnItem:getEndTime()
	local tb = unixTimeConvertToDate(self.serverTime);
	if tb ~= nil then
		local totalTime = os.time({year = tb.year, month = tb.month, day = tb.day, hour = 23, min = 59, sec = 59});
		return totalTime + 1;
		-- totalTime是当日23：59：59的秒数，第二天凌晨的话就需要+1
	end
	return 0;
end

function Lua_CopyZodiacBtnItem:dispose()
	Lua_CommonUtil.removeTimer(self, self.onLeftTimer);

	self:superCall("dispose");
end





--------------------------------------------------





Lua_CopyZodiacReward = class("Lua_CopyZodiacReward", Lua_ListCell);
function Lua_CopyZodiacReward:ctor(p)
	self:superCall("ctor", p, nil);
end

function Lua_CopyZodiacReward:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImg = Lua_ToolImage.new(self.content);
	self.itemImg:setDepth(10);
	self.itemImg:setLocation(0, 0, 0);
	self.itemImg:setCanClick(true);
end

function Lua_CopyZodiacReward:setData(data)
	self.itemImg.data = data;
end

function Lua_CopyZodiacReward:dispose()
	if self.itemImg ~= nil then
		self.itemImg:dispose();
		self.itemImg = nil;
	end
	
	self:superCall("dispose");
end